==> ejc-settle-api-3.0.0-20240603.013919-6-sources.jar: com/ejianc/business/settle/bean/SettlementCenterDcDrwgrpInfoVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 结算中心卷册信息表
 * 
 * @author generator
 * 
 */
public class SettlementCenterDcDrwgrpInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long contractId; // 承包合同id
    private Integer billState; // 单据状态
    private Long dcDrwgrpInfoId; // 卷册主键id
    private Long budgeId; // 预算书id
    private String settlementCenterMajor; // 结算中心专业
    private BigDecimal statisticalOutput; // 统计产值
    private Integer discriminateState; // -20-不需统计 0-未判别 10-需统计 100-已统计
    private Date firstNodeTime; // 数据生成的时间
    private Date secondNodeTime; // 综合管理员派发时间
    private Date thirdNodeTime; // 结算中心项目负责人派发时间
    private Date fourthNodeTime; // 结算中心专职提交时间
    private Date fifthNodeTime; // 专业主管审核时间
    private Date sixthNodeTime; // 结算中心项目负责人复审时间
    private Date seventhNodeTime; // 项目合同主管复审时间
    private Long firstNodeUserId; // 节点1综合管理员
    private Long secondNodeUserId; // 节点2结算中心项目负责人
    private Long thirdNodeUserId; // 节点3结算中心专职
    private Long fourthNodeUserId; // 节点4专业主管
    private Long fifthNodeUserId; // 节点5结算中心项目负责人
    private Long sixthNodeUserId; // 节点6项目合同主管
    private Long seventhNodeUserId; // 节点7综合管理员
    private Long createDeptId; // 创建部门id
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long engineeringTypeId; // 工程类别
    private Long subitem; // 子项--字典zx
    private String subitemName; // 子项名称
    private String flowState; // 流程状态
    private String flowStateName; // 流程状态名称
    private Date desiredTime; // 期望完成时间
    private Date eighthNodeTime; // 综合管理员复审归档时间
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String dcDrwgrpInfoCode; // 卷册编码
    private String contractCode;//承包合同code

    @ReferSerialTransfer(referCode = "pro-income-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "dc-drawinfo")
    public Long getDcDrwgrpInfoId() {
        return dcDrwgrpInfoId;
    }
    @ReferDeserialTransfer
    public void setDcDrwgrpInfoId(Long dcDrwgrpInfoId) {
        this.dcDrwgrpInfoId = dcDrwgrpInfoId;
    }
    @ReferSerialTransfer(referCode = "pro-income-budget")
    public Long getBudgeId() {
        return budgeId;
    }
    @ReferDeserialTransfer
    public void setBudgeId(Long budgeId) {
        this.budgeId = budgeId;
    }
    public String getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(String settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Integer getDiscriminateState() {
        return discriminateState;
    }

    public void setDiscriminateState(Integer discriminateState) {
        this.discriminateState = discriminateState;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFirstNodeUserId() {
        return firstNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFirstNodeUserId(Long firstNodeUserId) {
        this.firstNodeUserId = firstNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSecondNodeUserId() {
        return secondNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSecondNodeUserId(Long secondNodeUserId) {
        this.secondNodeUserId = secondNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }
    @ReferDeserialTransfer
    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFourthNodeUserId() {
        return fourthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFourthNodeUserId(Long fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getSubitem() {
        return subitem;
    }

    public void setSubitem(Long subitem) {
        this.subitem = subitem;
    }
    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }

    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }
}

==> ejc-settle-api-3.0.0-20240603.024334-7-sources.jar: com/ejianc/business/settle/bean/SettlementCenterDcDrwgrpInfoVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 结算中心卷册信息表
 * 
 * @author generator
 * 
 */
public class SettlementCenterDcDrwgrpInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long contractId; // 承包合同id
    private Integer billState; // 单据状态
    private Long dcDrwgrpInfoId; // 卷册主键id
    private Long budgeId; // 预算书id
    private String settlementCenterMajor; // 结算中心专业
    private BigDecimal statisticalOutput; // 统计产值
    private Integer discriminateState; // -20-不需统计 0-未判别 10-需统计 100-已统计
    private Date firstNodeTime; // 数据生成的时间
    private Date secondNodeTime; // 综合管理员派发时间
    private Date thirdNodeTime; // 结算中心项目负责人派发时间
    private Date fourthNodeTime; // 结算中心专职提交时间
    private Date fifthNodeTime; // 专业主管审核时间
    private Date sixthNodeTime; // 结算中心项目负责人复审时间
    private Date seventhNodeTime; // 项目合同主管复审时间
    private Long firstNodeUserId; // 节点1综合管理员
    private Long secondNodeUserId; // 节点2结算中心项目负责人
    private Long thirdNodeUserId; // 节点3结算中心专职
    private Long fourthNodeUserId; // 节点4专业主管
    private Long fifthNodeUserId; // 节点5结算中心项目负责人
    private Long sixthNodeUserId; // 节点6项目合同主管
    private Long seventhNodeUserId; // 节点7综合管理员
    private Long createDeptId; // 创建部门id
    private Long orgId; // 组织id
    private String orgCode; // 组织编码
    private String orgName; // 组织名称
    private Long parentOrgId; // 所属组织id
    private String parentOrgCode; // 所属组织编码
    private String parentOrgName; // 所属组织名称
    private Long engineeringTypeId; // 工程类别
    private Long subitem; // 子项--字典zx
    private String subitemName; // 子项名称
    private String flowState; // 流程状态
    private String flowStateName; // 流程状态名称
    private Date desiredTime; // 期望完成时间
    private Date eighthNodeTime; // 综合管理员复审归档时间
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private String projectCode; // 项目编码
    private String dcDrwgrpInfoCode; // 卷册编码
    private String contractCode;//承包合同code
    private Integer whetherUpgrade;//是否升版文件(0 否 1 是)

    @ReferSerialTransfer(referCode = "pro-income-contract")
    public Long getContractId() {
        return contractId;
    }
    @ReferDeserialTransfer
    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode = "dc-drawinfo")
    public Long getDcDrwgrpInfoId() {
        return dcDrwgrpInfoId;
    }
    @ReferDeserialTransfer
    public void setDcDrwgrpInfoId(Long dcDrwgrpInfoId) {
        this.dcDrwgrpInfoId = dcDrwgrpInfoId;
    }
    @ReferSerialTransfer(referCode = "pro-income-budget")
    public Long getBudgeId() {
        return budgeId;
    }
    @ReferDeserialTransfer
    public void setBudgeId(Long budgeId) {
        this.budgeId = budgeId;
    }
    public String getSettlementCenterMajor() {
        return settlementCenterMajor;
    }

    public void setSettlementCenterMajor(String settlementCenterMajor) {
        this.settlementCenterMajor = settlementCenterMajor;
    }
    public BigDecimal getStatisticalOutput() {
        return statisticalOutput;
    }

    public void setStatisticalOutput(BigDecimal statisticalOutput) {
        this.statisticalOutput = statisticalOutput;
    }
    public Integer getDiscriminateState() {
        return discriminateState;
    }

    public void setDiscriminateState(Integer discriminateState) {
        this.discriminateState = discriminateState;
    }
    public Date getFirstNodeTime() {
        return firstNodeTime;
    }

    public void setFirstNodeTime(Date firstNodeTime) {
        this.firstNodeTime = firstNodeTime;
    }
    public Date getSecondNodeTime() {
        return secondNodeTime;
    }

    public void setSecondNodeTime(Date secondNodeTime) {
        this.secondNodeTime = secondNodeTime;
    }
    public Date getThirdNodeTime() {
        return thirdNodeTime;
    }

    public void setThirdNodeTime(Date thirdNodeTime) {
        this.thirdNodeTime = thirdNodeTime;
    }
    public Date getFourthNodeTime() {
        return fourthNodeTime;
    }

    public void setFourthNodeTime(Date fourthNodeTime) {
        this.fourthNodeTime = fourthNodeTime;
    }
    public Date getFifthNodeTime() {
        return fifthNodeTime;
    }

    public void setFifthNodeTime(Date fifthNodeTime) {
        this.fifthNodeTime = fifthNodeTime;
    }
    public Date getSixthNodeTime() {
        return sixthNodeTime;
    }

    public void setSixthNodeTime(Date sixthNodeTime) {
        this.sixthNodeTime = sixthNodeTime;
    }
    public Date getSeventhNodeTime() {
        return seventhNodeTime;
    }

    public void setSeventhNodeTime(Date seventhNodeTime) {
        this.seventhNodeTime = seventhNodeTime;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFirstNodeUserId() {
        return firstNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFirstNodeUserId(Long firstNodeUserId) {
        this.firstNodeUserId = firstNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSecondNodeUserId() {
        return secondNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSecondNodeUserId(Long secondNodeUserId) {
        this.secondNodeUserId = secondNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getThirdNodeUserId() {
        return thirdNodeUserId;
    }
    @ReferDeserialTransfer
    public void setThirdNodeUserId(Long thirdNodeUserId) {
        this.thirdNodeUserId = thirdNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFourthNodeUserId() {
        return fourthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFourthNodeUserId(Long fourthNodeUserId) {
        this.fourthNodeUserId = fourthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getFifthNodeUserId() {
        return fifthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setFifthNodeUserId(Long fifthNodeUserId) {
        this.fifthNodeUserId = fifthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSixthNodeUserId() {
        return sixthNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSixthNodeUserId(Long sixthNodeUserId) {
        this.sixthNodeUserId = sixthNodeUserId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getSeventhNodeUserId() {
        return seventhNodeUserId;
    }
    @ReferDeserialTransfer
    public void setSeventhNodeUserId(Long seventhNodeUserId) {
        this.seventhNodeUserId = seventhNodeUserId;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }
    public Long getSubitem() {
        return subitem;
    }

    public void setSubitem(Long subitem) {
        this.subitem = subitem;
    }
    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }
    public String getFlowState() {
        return flowState;
    }

    public void setFlowState(String flowState) {
        this.flowState = flowState;
    }
    public String getFlowStateName() {
        return flowStateName;
    }

    public void setFlowStateName(String flowStateName) {
        this.flowStateName = flowStateName;
    }
    public Date getDesiredTime() {
        return desiredTime;
    }

    public void setDesiredTime(Date desiredTime) {
        this.desiredTime = desiredTime;
    }

    public Date getEighthNodeTime() {
        return eighthNodeTime;
    }

    public void setEighthNodeTime(Date eighthNodeTime) {
        this.eighthNodeTime = eighthNodeTime;
    }
    @ReferSerialTransfer(referCode = "project-set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getDcDrwgrpInfoCode() {
        return dcDrwgrpInfoCode;
    }

    public void setDcDrwgrpInfoCode(String dcDrwgrpInfoCode) {
        this.dcDrwgrpInfoCode = dcDrwgrpInfoCode;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public Integer getWhetherUpgrade() {
        return whetherUpgrade;
    }

    public void setWhetherUpgrade(Integer whetherUpgrade) {
        this.whetherUpgrade = whetherUpgrade;
    }
}
